@@ -11,7 +11,7 @@ import collections
 class global_bdata_fitter(global_fitter):
     
     # ======================================================================= #
-    def __init__(self,data,fn,shared,xlims=None,rebin=1,asym_mode='c',fixed=None):
+    def __init__(self, data, fn, xlims=None, rebin=1, asym_mode='c', **kwargs):
         """
             data:       list of bdata objects
             
@@ -19,10 +19,6 @@ class global_bdata_fitter(global_fitter):
                         must specify inputs explicitly (do not do def fn(*par)!)
                         must have len(fn) = len(runs) if list
                         
-            shared:     list of bool to indicate which parameters are shared. 
-                        True if shared
-                        len = number of parameters.
-                        
             xlims:      list of 2-tuples for (low,high) bounds on fitting range 
                             based on x values. If list is not depth 2, use this 
                             range on all runs.
@@ -35,19 +31,21 @@ class global_bdata_fitter(global_fitter):
                         parameters omitted.
             
             asym_mode:  asymmetry type to calculate and fit
+            
+            kwargs:     passed to global_fitter
         """
         
         # check input type
-        if type(data) in (bd.bdata,bd.bjoined):
+        if type(data) in (bd.bdata, bd.bjoined, bd.bmerged):
             data = [data]
         ndata = len(data)
         
         # Set rebin
-        if not isinstance(rebin,collections.Iterable):
+        if not isinstance(rebin, collections.Iterable):
             rebin = [rebin]*ndata
         
         # Get asymmetry
-        asym = np.asarray([d.asym(asym_mode,rebin=re) for d,re in zip(data,rebin)])
+        asym = np.asarray([d.asym(asym_mode, rebin=re) for d, re in zip(data, rebin)])
         
         # split into x,y,dy data sets
         x = asym[:,0]
@@ -79,4 +77,4 @@ class global_bdata_fitter(global_fitter):
             dy = np.array(dynew)
             
         # intialize
-        super(global_bdata_fitter,self).__init__(x,y,dy,fn,shared,fixed)
+        super(global_bdata_fitter,self).__init__(fn, x, y, dy=dy, **kwargs)
