@@ -6,7 +6,7 @@ from tkinter import *
 from tkinter import ttk, messagebox, filedialog
 from functools import partial
 from bdata import bdata, bmerged
-from bfit import logger_name,__version__
+from bfit import logger_name, __version__
 from scipy.special import gamma, polygamma
 from pandas.plotting import register_matplotlib_converters
 
@@ -15,8 +15,9 @@ from bfit.gui.popup_show_param import popup_show_param
 from bfit.gui.popup_param import popup_param
 from bfit.gui.popup_fit_results import popup_fit_results
 from bfit.gui.popup_fit_constraints import popup_fit_constraints
+from bfit.gui.popup_add_param import popup_add_param
 from bfit.fitting.decay_31mg import fa_31Mg
-from bfit.backend.entry_color_set import on_focusout,on_entry_click
+from bfit.backend.entry_color_set import on_focusout, on_entry_click
 from bfit.backend.raise_window import raise_window
 
 import numpy as np
@@ -45,11 +46,12 @@ class fit_files(object):
             par_label_entry:draw parameter label entry box
             pop_fitconstr:  object for fitting with constrained functions
             fit_data_tab:   containing frame (for destruction)
-            fit_function_title: title of fit function to use
+            fit_function_title: StringVar, title of fit function to use
             fit_function_title_box: combobox for fit function names
             fit_input:      fitting input values = (fn_name,ncomp,data_list)
             fit_lines:      Dict storing fitline objects
             fit_lines_old: dictionary of previously used fitline objects, keyed by run
+            fit_routine_label: label for fit routine
             fitter:         fitting object from self.bfit.routine_mod
             gchi_label:     Label for global chisquared    
             mode:           what type of run is this. 
@@ -58,7 +60,11 @@ class fit_files(object):
             n_component_box:Spinbox for number of fitting components
             par_label       StringVar, label for plotting parameter set
             plt:            self.bfit.plt
+            
+            pop_addpar:     popup for ading parameters which are combinations of others
             pop_fitres:     modelling popup, for continuity between button presses
+            pop_fitcontr:   popup for fitting constrained values
+            
             probe_label:    Label for probe species
             runframe:       frame for displaying fit results and inputs
             runmode_label:  display run mode 
@@ -98,7 +104,7 @@ class fit_files(object):
         self.share_var = {}
         self.fitter = self.bfit.routine_mod.fitter(keyfn = bfit.get_run_key,
                                                    probe_species = bfit.probe_species.get())
-        self.draw_components = bfit.draw_components
+        self.draw_components = list(bfit.draw_components)
         self.fit_data_tab = fit_data_tab
         self.plt = self.bfit.plt
         
@@ -135,16 +141,14 @@ class fit_files(object):
                 command=lambda:self.populate_param(force_modify=True))
         
         # fit and other buttons
-        fit_button = ttk.Button(fn_select_frame,text='Fit',command=self.do_fit,\
+        fit_button = ttk.Button(fn_select_frame,text='        Fit        ',command=self.do_fit,\
                                 pad=1)
         constraint_button = ttk.Button(fn_select_frame,text='Constrained Fit',
                                        command=self.do_fit_constraints,pad=1)
-        set_param_button = ttk.Button(fn_select_frame,text='Set Result as P0',
+        set_param_button = ttk.Button(fn_select_frame,text='   Set Result as P0   ',
                         command=self.do_set_result_as_initial,pad=1)                        
-        reset_param_button = ttk.Button(fn_select_frame,text='Reset P0',
+        reset_param_button = ttk.Button(fn_select_frame,text='     Reset P0     ',
                         command=self.do_reset_initial,pad=1)
-        gui_param_button = ttk.Button(fn_select_frame,text='P0 Finder',
-                        command=self.do_gui_param,pad=1)
             
         # GRIDDING
             
@@ -160,7 +164,6 @@ class fit_files(object):
         constraint_button.grid(column=c,row=0,padx=5,pady=1,sticky=(W,E)); c+=1
         set_param_button.grid(column=c,row=0,padx=5,pady=1,sticky=W); c+=1
         reset_param_button.grid(column=c,row=0,padx=5,pady=1,sticky=W); c+=1
-        gui_param_button.grid(column=c,row=0,padx=5,pady=1,sticky=W); c+=1
         
         # MID FRAME -----------------------------------------------------------
         
@@ -198,7 +201,7 @@ class fit_files(object):
         
         # fitting routine
         fit_routine_label_frame = ttk.Labelframe(fit_data_tab,pad=(10,5,10,5),
-                text='Fitting Routine',)
+                text='Minimizer',)
         self.fit_routine_label = ttk.Label(fit_routine_label_frame,text="",
                                            justify=CENTER)
         
@@ -268,18 +271,19 @@ class fit_files(object):
         
         # draw and export buttons
         button_frame = Frame(results_frame)
-        draw_button = ttk.Button(button_frame,text='Draw',command=self.draw_param)
-        update_button = ttk.Button(button_frame,text='Update',command=self.update_param)
-        export_button = ttk.Button(button_frame,text='Export',command=self.export)
-        show_button = ttk.Button(button_frame,text='Compare',command=self.show_all_results)
+        draw_button = ttk.Button(button_frame,text='Draw', command=self.draw_param)
+        update_button = ttk.Button(button_frame,text='Update', command=self.update_param)
+        export_button = ttk.Button(button_frame,text='Export', command=self.export)
+        show_button = ttk.Button(button_frame,text='Compare', command=self.show_all_results)
         model_fit_button = ttk.Button(button_frame,text='Fit a\nModel',
                                       command=self.do_fit_model)
         
+        
         # menus for x and y values
-        ttk.Label(results_frame,text="x axis:").grid(column=0,row=1)
-        ttk.Label(results_frame,text="y axis:").grid(column=0,row=2)
-        ttk.Label(results_frame,text="Annotation:").grid(column=0,row=3)
-        ttk.Label(results_frame,text="Label:").grid(column=0,row=4)
+        x_button = ttk.Button(results_frame,text="x axis:", command=self.do_add_param, pad=0)
+        y_button = ttk.Button(results_frame,text="y axis:", command=self.do_add_param, pad=0)
+        ann_button = ttk.Button(results_frame,text=" Annotation:", command=self.do_add_param, pad=0)
+        label_label = ttk.Label(results_frame,text="Label:")
         
         self.xaxis = StringVar()
         self.yaxis = StringVar()
@@ -302,22 +306,27 @@ class fit_files(object):
                                     textvariable=self.par_label,width=21)
         
         # gridding
-        button_frame.grid(column=0,row=0,columnspan=2)
-        draw_button.grid(column=0,row=0,padx=5,pady=5)
-        update_button.grid(column=0,row=1,padx=5,pady=5)
-        show_button.grid(column=1,row=0,padx=5,pady=5)
-        export_button.grid(column=1,row=1,padx=5,pady=5)
-        model_fit_button.grid(column=2,row=0,rowspan=2,pady=5,sticky=(N,S))
+        button_frame.grid(column=0, row=0, columnspan=2)
+        draw_button.grid(column=0, row=0, padx=5, pady=5)
+        update_button.grid(column=0, row=1, padx=5, pady=5)
+        show_button.grid(column=1, row=0, padx=5, pady=5)
+        export_button.grid(column=1, row=1, padx=5, pady=5)
+        model_fit_button.grid(column=2, row=0, rowspan=2, pady=5, sticky=(N, S))
         
-        self.xaxis_combobox.grid(column=1,row=1,pady=5)
-        self.yaxis_combobox.grid(column=1,row=2,pady=5)
-        self.annotation_combobox.grid(column=1,row=3,pady=5)
-        self.par_label_entry.grid(column=1,row=4,pady=5)
+        x_button.grid(column=0, row=1, sticky=(E,W), padx=5)
+        y_button.grid(column=0, row=2, sticky=(E,W), padx=5)
+        ann_button.grid(column=0, row=3, sticky=(E,W), padx=5)
+        label_label.grid(column=0, row=4, sticky=(E,W), padx=10)
+        
+        self.xaxis_combobox.grid(column=1, row=1, pady=5)
+        self.yaxis_combobox.grid(column=1, row=2, pady=5)
+        self.annotation_combobox.grid(column=1, row=3, pady=5)
+        self.par_label_entry.grid(column=1,row=4, pady=5)
         
         # save/load state -----------------------
-        state_frame = ttk.Labelframe(fit_data_tab,text='Program State',pad=5)
-        state_save_button = ttk.Button(state_frame,text='Save',command=self.save_state)
-        state_load_button = ttk.Button(state_frame,text='Load',command=self.load_state)
+        state_frame = ttk.Labelframe(fit_data_tab, text='Program State', pad=5)
+        state_save_button = ttk.Button(state_frame, text='Save', command=self.save_state)
+        state_load_button = ttk.Button(state_frame, text='Load', command=self.load_state)
        
         state_save_button.grid(column=0,row=0,padx=5,pady=5)
         state_load_button.grid(column=1,row=0,padx=5,pady=5)
@@ -553,13 +562,13 @@ class fit_files(object):
             
             if ncomp > 1: 
                 for i in range(ncomp):
-                    parlst.append('Beta-Avg 1/<T1_%d>' % i)
+                    parlst.append('Beta-Avg 1/<T1>_%d' % i)
             else:
                 parlst.append('Beta-Avg 1/<T1>')
             
-        self.xaxis_combobox['values'] = ['']+parlst+lst
-        self.yaxis_combobox['values'] = ['']+parlst+lst
-        self.annotation_combobox['values'] = ['']+parlst+lst
+        self.xaxis_combobox['values'] = [''] + parlst + lst
+        self.yaxis_combobox['values'] = [''] + parlst + lst
+        self.annotation_combobox['values'] = [''] + parlst + lst
 
         self._make_shared_var_dict()
             
@@ -574,6 +583,25 @@ class fit_files(object):
         # reset modify all value
         self.set_as_group.set(modify_all_value)
             
+    # ======================================================================= #
+    def do_add_param(self, *args):
+        """Launch popup for adding user-defined parameters to draw"""
+        if hasattr(self,'pop_addpar'):
+            p = self.pop_addpar
+            
+            # don't make more than one window
+            if Toplevel.winfo_exists(p.win): 
+                p.win.lift()
+                return
+            
+            # make a new window, using old inputs and outputs
+            self.pop_addpar = popup_add_param(self.bfit,
+                                    input_fn_text=p.input_fn_text)
+        
+        # make entirely new window
+        else:
+            self.pop_addpar = popup_add_param(self.bfit)
+        
     # ======================================================================= #
     def do_fit(self,*args):
         # fitter
@@ -610,7 +638,6 @@ class fit_files(object):
             
             # bdata object
             bdfit = fitline.dataline.bdfit
-            bdataobj = bdfit.bd
             
             # pdict
             pdict = {}
@@ -651,25 +678,18 @@ class fit_files(object):
                 doptions['omit'] = dline.bin_remove.get()
                 if doptions['omit'] == dline.bin_remove_starter_line: 
                     doptions['omit'] = ''
-                
-            elif self.mode == '20':
+            elif self.mode in ('20','2h','2e'):
                 pass
-                
-            elif self.mode == '2h':
-                pass
-                
-            elif self.mode == '2e':
-                pass
-            
             else:
-                self.logger.error('Fitting mode not recognized')
-                raise RuntimeError('Fitting mode not recognized')
+                msg = 'Fitting mode %s not recognized' % self.mode
+                self.logger.error(msg)
+                raise RuntimeError(msg)
             
             # make data list
-            data_list.append([bdataobj,pdict,doptions])
+            data_list.append([bdfit, pdict, doptions])
         
         # call fitter with error message, potentially
-        self.fit_input = (fn_name,ncomp,data_list)
+        self.fit_input = (fn_name, ncomp, data_list)
         fit_status_window = self.make_fit_status_window()
         
         # do fit then kill window
@@ -677,7 +697,8 @@ class fit_files(object):
             self.logger.info('Fitting run %s: %s',self.bfit.get_run_key(d[0]),d[1:])    
         try:
             # fit_output keyed as {run:[key/par/cov/chi/fnpointer]}
-            fit_output,gchi = fitter(fn_name=fn_name,ncomp=ncomp,
+            fit_output,gchi = fitter(fn_name=fn_name,
+                                     ncomp=ncomp,
                                      data_list=data_list,
                                      hist_select=self.bfit.hist_select,
                                      asym_mode=self.bfit.get_asym_mode(self),
@@ -733,9 +754,14 @@ class fit_files(object):
             warnings.simplefilter("ignore")
             self.bfit.fetch_files.draw_all(figstyle='fit',ignore_check=False)
         
-        if len(self.fit_lines.keys())>self.bfit.legend_max_draw:
-            self.plt.gca('fit').get_legend().remove()
-            self.plt.tight_layout('fit')
+        if len(self.fit_lines.keys()) > self.bfit.legend_max_draw:
+            
+            try:
+                self.plt.gca('fit').get_legend().remove()
+            except AttributeError:
+                pass
+            else:
+                self.plt.tight_layout('fit')
         
         # reset style and asym mode 
         self.bfit.draw_style.set(style)
@@ -1035,7 +1061,22 @@ class fit_files(object):
             messagebox.showerror("Error",
                     'Drawing parameter "%s" or "%s" not found' % (xdraw,ydraw))
             raise err from None
-            
+        
+        # get asymmetric errors
+        if type(xerrs) is tuple:
+            xerrs_l = xerrs[0]
+            xerrs_h = xerrs[1]
+        else:
+            xerrs_l = xerrs
+            xerrs_h = xerrs
+        
+        if type(yerrs) is tuple:
+            yerrs_l = yerrs[0]
+            yerrs_h = yerrs[1]
+        else:
+            yerrs_l = yerrs
+            yerrs_h = yerrs
+        
         # get annotation
         if ann != '':
             try:
@@ -1060,8 +1101,10 @@ class fit_files(object):
         xvals = np.asarray(xvals)[idx]
         yvals = np.asarray(yvals)[idx]
         
-        xerrs = np.asarray(xerrs)[idx]
-        yerrs = np.asarray(yerrs)[idx]
+        xerrs_l = np.asarray(xerrs_l)[idx]
+        yerrs_l = np.asarray(yerrs_l)[idx]
+        xerrs_h = np.asarray(xerrs_h)[idx]
+        yerrs_h = np.asarray(yerrs_h)[idx]
         
         if ann is not None:
             ann = np.asarray(ann)[idx]
@@ -1117,17 +1160,77 @@ class fit_files(object):
             except AttributeError:
                 pass
             
+        # remove component label
+        ncomp = self.n_component.get()
+        xsuffix = ''
+        ysuffix = ''
+        if ncomp > 1:
+        
+            fn_params = self.fitter.gen_param_names(self.fit_function_title.get(), ncomp)
+            
+            if xdraw in fn_params or 'Beta-Avg 1/<T1>' in xdraw:
+                spl = xdraw.split('_')
+                xdraw = '_'.join(spl[:-1])
+                xsuffix = ' [%s]' % spl[-1]
+            
+            if ydraw in fn_params or 'Beta-Avg 1/<T1>' in ydraw:
+                spl = ydraw.split('_')
+                ydraw = '_'.join(spl[:-1])
+                ysuffix = ' [%s]' % spl[-1]
+                
+            
+        # pretty labels
+        xdraw = self.fitter.pretty_param.get(xdraw, xdraw)
+        ydraw = self.fitter.pretty_param.get(ydraw, ydraw)
+        
+        # add suffix for multiple labels
+        xdraw = xdraw + xsuffix
+        ydraw = ydraw + ysuffix
+        
+        # attempt to insert units and scale
+        unit_scale, unit = self.bfit.units.get(self.mode, [1,''])
+        
+        if '%s' in xdraw:        
+            xdraw = xdraw % unit
+            xvals *= unit_scale
+            xerrs_h *= unit_scale
+            xerrs_l *= unit_scale
+        if '%s' in ydraw:
+            ydraw = ydraw % unit
+            yvals *= unit_scale
+            yerrs_h *= unit_scale
+            yerrs_l *= unit_scale
+        
+        # check for nan errors
+        if all(np.isnan(xerrs_h)): xerrs_h = None
+        if all(np.isnan(xerrs_l)): xerrs_l = None
+        if all(np.isnan(yerrs_h)): yerrs_h = None
+        if all(np.isnan(yerrs_l)): yerrs_l = None
+        
+        if xerrs_h is None and xerrs_l is None:     xerr = None
+        else:                                       xerr = (xerrs_l, xerrs_h)
+        if yerrs_h is None and yerrs_l is None:     yerr = None
+        else:                                       yerr = (yerrs_l, yerrs_h)
+        
         # draw
-        f = self.plt.errorbar(figstyle,draw_id,xvals,yvals,xerr=xerrs,yerr=yerrs,
-                              label=draw_id,annot_label=mouse_label,**self.bfit.style)
-        self._annotate(draw_id,xvals,yvals,ann,color=f[0].get_color(),unique=False)
+        f = self.plt.errorbar(  figstyle,
+                                draw_id,
+                                xvals,
+                                yvals,
+                                xerr = xerr,
+                                yerr = yerr,
+                                label=draw_id,
+                                annot_label=mouse_label,
+                                **self.bfit.style)
+        self._annotate(draw_id, xvals, yvals, ann, color=f[0].get_color(), unique=False)
         
         # format date x axis
         if xerrs is None:   self.plt.gcf(figstyle).autofmt_xdate()
         
+        
         # plot elements
-        self.plt.xlabel(figstyle,xdraw)
-        self.plt.ylabel(figstyle,ydraw)
+        self.plt.xlabel(figstyle, xdraw)
+        self.plt.ylabel(figstyle, ydraw)
         self.plt.tight_layout(figstyle)
         
         if draw_id:
@@ -1137,7 +1240,7 @@ class fit_files(object):
         raise_window()
         
     # ======================================================================= #
-    def export(self,savetofile=True):
+    def export(self, savetofile=True):
         """Export the fit parameter and file headers"""
         # get values and errors
         val = {}
@@ -1153,7 +1256,12 @@ class fit_files(object):
                 traceback.print_exc()
             else:
                 val[v] = v2[0]
-                val['Error '+v] = v2[1]
+                
+                if type(v2[1]) is tuple:                     
+                    val['Error- '+v] = v2[1][0]
+                    val['Error+ '+v] = v2[1][1]
+                else:
+                    val['Error '+v] = v2[1]
         
         # make data frame for output
         df = pd.DataFrame(val)
@@ -1195,7 +1303,7 @@ class fit_files(object):
             return df
         
     # ======================================================================= #
-    def export_fit(self,savetofile=True):
+    def export_fit(self, savetofile=True):
         """Export the fit lines as csv files"""
         
         # filename
@@ -1263,7 +1371,7 @@ class fit_files(object):
             self.logger.info('Exporting fit to %s',fname)
     
     # ======================================================================= #
-    def get_values(self,select):
+    def get_values(self, select):
         """ Get plottable values"""
         
         data = self.bfit.data
@@ -1364,9 +1472,16 @@ class fit_files(object):
             for r in runs:
                 T1i = data[r].fitpar['res']['1_T1'+comp_num]
                 T1 = 1/T1i
-                dT1 = data[r].fitpar['dres']['1_T1'+comp_num]/(T1i**2)
+                dT1_l = data[r].fitpar['dres-']['1_T1'+comp_num]/(T1i**2)
+                dT1_u = data[r].fitpar['dres+']['1_T1'+comp_num]/(T1i**2)
+                
+                dT1 = np.sqrt(np.square(dT1_l) + np.square(dT1_u))
+                
                 beta = data[r].fitpar['res']['beta'+comp_num]
-                dbeta = data[r].fitpar['dres']['beta'+comp_num]
+                dbeta_l = data[r].fitpar['dres-']['beta'+comp_num]
+                dbeta_u = data[r].fitpar['dres+']['beta'+comp_num]
+                
+                dbeta = np.sqrt(np.square(dbeta_l) + np.square(dbeta_u))
                 
                 # take average
                 betai = 1./beta
@@ -1415,7 +1530,7 @@ class fit_files(object):
             rate = lambda b : np.sum([b.hist['NBM'+h].data \
                                     for h in ('F+','F-','B-','B+')])/b.duration
             val = [rate(data[r].bd) for r in runs]
-            err = [np.nan for r in runs]        
+            err = np.full(len(val), np.nan)
             
         elif 'Sample Rate (count/s)' in select:
             hist = ('F+','F-','B-','B+') if data[runs[0]].area == 'BNMR' \
@@ -1423,23 +1538,32 @@ class fit_files(object):
                 
             rate = lambda b : np.sum([b.hist[h].data for h in hist])/b.duration
             val = [rate(data[r].bd) for r in runs]
-            err = [np.nan for r in runs]        
+            err = np.full(len(val), np.nan)     
             
         # fitted parameter options
         elif select in parnames:
             val = []
-            err = []
+            err_l = []
+            err_u = []
             
             for r in runs:
                 try:
                     val.append(data[r].fitpar['res'][select])
-                    err.append(data[r].fitpar['dres'][select])
+                    err_l.append(data[r].fitpar['dres-'][select])
+                    err_u.append(data[r].fitpar['dres+'][select])
                 except KeyError:
                     val.append(np.nan)
-                    err.append(np.nan)
-    
+                    err_l.append(np.nan)
+                    err_u.append(np.nan)
+            err = (err_l, err_u)
+            
+        # check user-defined parameters
+        elif select in self.pop_addpar.set_par.keys():
+            val = self.pop_addpar.set_par[select]()
+            err = np.full(len(val), np.nan)
+        
         try:
-            return (val,err)
+            return (val, err)
         except UnboundLocalError:
             self.logger.warning('Parameter selection "%s" not found' % select)
             raise AttributeError('Selection "%s" not found' % select) from None
@@ -1526,7 +1650,8 @@ class fit_files(object):
             # set fit inputs
             d_fitdata[id].set_fitpar({p:[parentry[p]['p0'],
                                          parentry[p]['blo'],
-                                         parentry[p]['bhi']] for p in parentry})
+                                         parentry[p]['bhi'],
+                                         parentry[p]['fixed']] for p in parentry})
             
             # get chisq
             keylist = self.fitter.gen_param_names(from_file['fitfn'],
@@ -1559,7 +1684,8 @@ class fit_files(object):
             # set fit results
             d_fitdata[id].set_fitresult([keylist,
                               [float(parentry[p]['res']) for p in keylist],
-                              [float(parentry[p]['dres']) for p in keylist],
+                              [float(parentry[p]['dres-']) for p in keylist],
+                              [float(parentry[p]['dres+']) for p in keylist],
                               chi,
                               fitfn1]
                             )
@@ -1568,6 +1694,21 @@ class fit_files(object):
         self.xlo.set(from_file['xlo'])
         self.xhi.set(from_file['xhi'])
         
+        # set minimizer
+        self.bfit.minimizer.set(from_file['minimizer'])
+        self.bfit.set_fit_routine()
+        
+        # set menu options
+        self.bfit.norm_with_param.set(from_file['norm_with_param'])
+        self.bfit.draw_standardized_res.set(from_file['draw_standardized_res'])
+        self.bfit.use_nbm.set(from_file['use_nbm'])
+        self.bfit.draw_ppm.set(from_file['draw_ppm'])
+        self.bfit.thermo_channel.set(from_file['thermo_channel'])
+        self.bfit.units = from_file['units']
+        self.bfit.label_default.set(from_file['label_default'])
+        self.bfit.ppm_reference = from_file['ppm_reference']
+        self.bfit.update_period = from_file['update_period']
+        
     # ======================================================================= #
     def make_fit_status_window(self):
         """Window to show that fitting is in progress"""
@@ -1609,7 +1750,7 @@ class fit_files(object):
         
         setall = self.set_as_group.get()
         for k in self.fit_lines.keys():
-            self.fit_lines[k].set_input(source,par,column,setall)        
+            self.fit_lines[k].set_input(source, par, column, setall)        
     
     # ======================================================================= #
     def return_binder(self):
@@ -1681,6 +1822,16 @@ class fit_files(object):
         to_file['ncomponents'] = self.n_component.get()
         to_file['gchi'] = self.gchi_label['text']
         to_file['probe_species'] = self.bfit.probe_species.get()
+        to_file['minimizer'] = self.bfit.minimizer.get()
+        to_file['norm_with_param'] = self.bfit.norm_with_param.get()
+        to_file['draw_standardized_res'] = self.bfit.draw_standardized_res.get()
+        to_file['use_nbm'] = self.bfit.use_nbm.get()
+        to_file['draw_ppm'] = self.bfit.draw_ppm.get()
+        to_file['thermo_channel'] = self.bfit.thermo_channel.get()
+        to_file['units'] = self.bfit.units
+        to_file['label_default'] = self.bfit.label_default.get()
+        to_file['ppm_reference'] = self.bfit.ppm_reference
+        to_file['update_period'] = self.bfit.update_period
         
         # get parameter values from fitlines
         fitlines = self.fit_lines
@@ -1781,11 +1932,11 @@ class fitline(object):
     """
     
     n_runs_max = 5      # number of runs before scrollbar appears
-    collist = ['p0','blo','bhi','res','dres','chi','fixed','shared']
+    collist = ['p0', 'blo', 'bhi', 'res', 'dres-', 'dres+', 'chi', 'fixed', 'shared']
     selected = 0        # index of selected run 
     
     # ======================================================================= #
-    def __init__(self,bfit,parent,dataline,row):
+    def __init__(self,bfit, parent, dataline, row):
         """
             Inputs:
                 bfit:       top level pointer
@@ -1844,7 +1995,8 @@ class fitline(object):
         ttk.Label(fitframe,text='Low Bound').grid(    column=c,row=1,padx=5); c+=1
         ttk.Label(fitframe,text='High Bound').grid(   column=c,row=1,padx=5); c+=1
         result_comp_button.grid(column=c,row=1,padx=5,pady=2,sticky=(E,W)); c+=1
-        ttk.Label(fitframe,text='Error').grid(        column=c,row=1,padx=5); c+=1
+        ttk.Label(fitframe,text='Error (-)').grid(        column=c,row=1,padx=5); c+=1
+        ttk.Label(fitframe,text='Error (+)').grid(        column=c,row=1,padx=5); c+=1
         ttk.Label(fitframe,text='ChiSq').grid(        column=c,row=1,padx=5); c+=1
         ttk.Label(fitframe,text='Fixed').grid(        column=c,row=1,padx=5); c+=1
         ttk.Label(fitframe,text='Shared').grid(       column=c,row=1,padx=5); c+=1
@@ -1988,7 +2140,7 @@ class fitline(object):
             p = plist[i]
             
             # clear text in parentry fields
-            for col in ('res','dres','chi'):
+            for col in ('res','dres-','dres+','chi'):
                 if col in self.parentry[p].keys():  # exception needed for chi
                     par = self.parentry[p][col][1]
                     par.delete(0,'end')
@@ -2018,14 +2170,19 @@ class fitline(object):
             par['state'] = 'readonly'
             par['foreground'] = colors.foreground
             
-            dpar_val = StringVar()
-            dpar = ttk.Entry(fitframe,textvariable=dpar_val,width=15)
-            dpar['state'] = 'readonly'
-            dpar['foreground'] = colors.foreground
+            dpar_val_l = StringVar()
+            dpar_val_u = StringVar()
+            dpar_l = ttk.Entry(fitframe, textvariable=dpar_val_l, width=15)
+            dpar_u = ttk.Entry(fitframe, textvariable=dpar_val_u, width=15)
+            dpar_l['state'] = 'readonly'
+            dpar_l['foreground'] = colors.foreground
+            dpar_u['state'] = 'readonly'
+            dpar_u['foreground'] = colors.foreground
                                      
             par. grid(column=c,row=r,padx=5,sticky=E); c += 1
-            dpar.grid(column=c,row=r,padx=5,sticky=E); c += 1
-
+            dpar_l.grid(column=c,row=r,padx=5,sticky=E); c += 1
+            dpar_u.grid(column=c,row=r,padx=5,sticky=E); c += 1
+            
             # do chi only once
             if i==0:
                 chi_val = StringVar()
@@ -2039,20 +2196,21 @@ class fitline(object):
             
             # save ttk.Entry objects in dictionary [parname][colname]
             self.parentry[p]['res'] = (par_val,par)
-            self.parentry[p]['dres'] = (dpar_val,dpar)
+            self.parentry[p]['dres-'] = (dpar_val_l,dpar_l)
+            self.parentry[p]['dres+'] = (dpar_val_u,dpar_u)
             
             # do fixed box
             value = BooleanVar()
-            entry = ttk.Checkbutton(fitframe,text='',\
-                                     variable=value,onvalue=True,offvalue=False)
-            entry.grid(column=c,row=r,padx=5,sticky=E); c += 1
-            self.parentry[p]['fixed'] = (value,entry)
+            entry = ttk.Checkbutton(fitframe, text='',\
+                                     variable=value, onvalue=True, offvalue=False)
+            entry.grid(column=c, row=r, padx=5, sticky=E); c += 1
+            self.parentry[p]['fixed'] = (value, entry)
             value.set(fitdat.fitpar['fixed'][p])
             
             # do shared box
-            entry = ttk.Checkbutton(fitframe,text='',onvalue=True,offvalue=False)
-            entry.grid(column=c,row=r,padx=5,sticky=E); c += 1
-            self.parentry[p]['shared'] = [value,entry]
+            entry = ttk.Checkbutton(fitframe, text='', onvalue=True, offvalue=False)
+            entry.grid(column=c, row=r, padx=5, sticky=E); c += 1
+            self.parentry[p]['shared'] = [value, entry]
             
         # set p0 synchronization ----------------------------------------------
         
@@ -2184,7 +2342,7 @@ class fitline(object):
         self.fitframe.update_idletasks()
     
     # ======================================================================= #
-    def set_input(self,source_line,parameter,column,set_all):
+    def set_input(self, source_line, parameter, column, set_all):
         """
             Set the input value for a given parameter to match the value in 
             another fitline
@@ -2202,11 +2360,7 @@ class fitline(object):
             source_entry = source_line.parentry[parameter]
         except KeyError:
             return
-        
-        # special case: fixed checkbox
-        if not set_all and column == 'fixed':
-            return
-        
+              
         # set value
         if set_all or shared:
             
@@ -2244,7 +2398,8 @@ class fitline(object):
             disp = displays[parname]
             showstr = "%"+".%df" % self.bfit.rounding
             disp['res'][0].set(showstr % data.fitpar['res'][parname])
-            disp['dres'][0].set(showstr % data.fitpar['dres'][parname])
+            disp['dres-'][0].set(showstr % data.fitpar['dres-'][parname])
+            disp['dres+'][0].set(showstr % data.fitpar['dres+'][parname])
             
             if 'chi' in disp.keys():
                 disp['chi'][0].set('%.2f' % chi)
